@@ -22,9 +22,11 @@ from mypy_boto3_accessanalyzer.paginator import (
     ListAnalyzersPaginator,
     ListArchiveRulesPaginator,
     ListFindingsPaginator,
+    ListPolicyGenerationsPaginator,
     ValidatePolicyPaginator,
 )
 from mypy_boto3_accessanalyzer.type_defs import (
+    CloudTrailDetailsTypeDef,
     ConfigurationTypeDef,
     CreateAccessPreviewResponseTypeDef,
     CreateAnalyzerResponseTypeDef,
@@ -34,6 +36,7 @@ from mypy_boto3_accessanalyzer.type_defs import (
     GetAnalyzerResponseTypeDef,
     GetArchiveRuleResponseTypeDef,
     GetFindingResponseTypeDef,
+    GetGeneratedPolicyResponseTypeDef,
     InlineArchiveRuleTypeDef,
     ListAccessPreviewFindingsResponseTypeDef,
     ListAccessPreviewsResponseTypeDef,
@@ -41,8 +44,11 @@ from mypy_boto3_accessanalyzer.type_defs import (
     ListAnalyzersResponseTypeDef,
     ListArchiveRulesResponseTypeDef,
     ListFindingsResponseTypeDef,
+    ListPolicyGenerationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    PolicyGenerationDetailsTypeDef,
     SortCriteriaTypeDef,
+    StartPolicyGenerationResponseTypeDef,
     ValidatePolicyResponseTypeDef,
 )
 
@@ -76,7 +82,7 @@ class Exceptions:
 
 class AccessAnalyzerClient:
     """
-    [AccessAnalyzer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
+    [AccessAnalyzer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client)
     """
 
     meta: ClientMeta
@@ -84,12 +90,17 @@ class AccessAnalyzerClient:
 
     def apply_archive_rule(self, analyzerArn: str, ruleName: str, clientToken: str = None) -> None:
         """
-        [Client.apply_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
+        [Client.apply_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.apply_archive_rule)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.can_paginate)
+        """
+
+    def cancel_policy_generation(self, jobId: str) -> Dict[str, Any]:
+        """
+        [Client.cancel_policy_generation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.cancel_policy_generation)
         """
 
     def create_access_preview(
@@ -99,7 +110,7 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> CreateAccessPreviewResponseTypeDef:
         """
-        [Client.create_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
+        [Client.create_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_access_preview)
         """
 
     def create_analyzer(
@@ -111,7 +122,7 @@ class AccessAnalyzerClient:
         tags: Dict[str, str] = None,
     ) -> CreateAnalyzerResponseTypeDef:
         """
-        [Client.create_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
+        [Client.create_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_analyzer)
         """
 
     def create_archive_rule(
@@ -122,19 +133,19 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> None:
         """
-        [Client.create_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
+        [Client.create_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.create_archive_rule)
         """
 
     def delete_analyzer(self, analyzerName: str, clientToken: str = None) -> None:
         """
-        [Client.delete_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
+        [Client.delete_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_analyzer)
         """
 
     def delete_archive_rule(
         self, analyzerName: str, ruleName: str, clientToken: str = None
     ) -> None:
         """
-        [Client.delete_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
+        [Client.delete_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.delete_archive_rule)
         """
 
     def generate_presigned_url(
@@ -145,36 +156,46 @@ class AccessAnalyzerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.generate_presigned_url)
         """
 
     def get_access_preview(
         self, accessPreviewId: str, analyzerArn: str
     ) -> GetAccessPreviewResponseTypeDef:
         """
-        [Client.get_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
+        [Client.get_access_preview documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_access_preview)
         """
 
     def get_analyzed_resource(
         self, analyzerArn: str, resourceArn: str
     ) -> GetAnalyzedResourceResponseTypeDef:
         """
-        [Client.get_analyzed_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
+        [Client.get_analyzed_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzed_resource)
         """
 
     def get_analyzer(self, analyzerName: str) -> GetAnalyzerResponseTypeDef:
         """
-        [Client.get_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
+        [Client.get_analyzer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_analyzer)
         """
 
     def get_archive_rule(self, analyzerName: str, ruleName: str) -> GetArchiveRuleResponseTypeDef:
         """
-        [Client.get_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
+        [Client.get_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_archive_rule)
         """
 
     def get_finding(self, analyzerArn: str, id: str) -> GetFindingResponseTypeDef:
         """
-        [Client.get_finding documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        [Client.get_finding documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_finding)
+        """
+
+    def get_generated_policy(
+        self,
+        jobId: str,
+        includeResourcePlaceholders: bool = None,
+        includeServiceLevelTemplate: bool = None,
+    ) -> GetGeneratedPolicyResponseTypeDef:
+        """
+        [Client.get_generated_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.get_generated_policy)
         """
 
     def list_access_preview_findings(
@@ -186,14 +207,14 @@ class AccessAnalyzerClient:
         nextToken: str = None,
     ) -> ListAccessPreviewFindingsResponseTypeDef:
         """
-        [Client.list_access_preview_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
+        [Client.list_access_preview_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_preview_findings)
         """
 
     def list_access_previews(
         self, analyzerArn: str, maxResults: int = None, nextToken: str = None
     ) -> ListAccessPreviewsResponseTypeDef:
         """
-        [Client.list_access_previews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
+        [Client.list_access_previews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_access_previews)
         """
 
     def list_analyzed_resources(
@@ -212,7 +233,7 @@ class AccessAnalyzerClient:
         ] = None,
     ) -> ListAnalyzedResourcesResponseTypeDef:
         """
-        [Client.list_analyzed_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
+        [Client.list_analyzed_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzed_resources)
         """
 
     def list_analyzers(
@@ -222,14 +243,14 @@ class AccessAnalyzerClient:
         type: Literal["ACCOUNT", "ORGANIZATION"] = None,
     ) -> ListAnalyzersResponseTypeDef:
         """
-        [Client.list_analyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
+        [Client.list_analyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_analyzers)
         """
 
     def list_archive_rules(
         self, analyzerName: str, maxResults: int = None, nextToken: str = None
     ) -> ListArchiveRulesResponseTypeDef:
         """
-        [Client.list_archive_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
+        [Client.list_archive_rules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_archive_rules)
         """
 
     def list_findings(
@@ -241,27 +262,44 @@ class AccessAnalyzerClient:
         sort: SortCriteriaTypeDef = None,
     ) -> ListFindingsResponseTypeDef:
         """
-        [Client.list_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        [Client.list_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_findings)
+        """
+
+    def list_policy_generations(
+        self, maxResults: int = None, nextToken: str = None, principalArn: str = None
+    ) -> ListPolicyGenerationsResponseTypeDef:
+        """
+        [Client.list_policy_generations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_policy_generations)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.list_tags_for_resource)
+        """
+
+    def start_policy_generation(
+        self,
+        policyGenerationDetails: PolicyGenerationDetailsTypeDef,
+        clientToken: str = None,
+        cloudTrailDetails: CloudTrailDetailsTypeDef = None,
+    ) -> StartPolicyGenerationResponseTypeDef:
+        """
+        [Client.start_policy_generation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_policy_generation)
         """
 
     def start_resource_scan(self, analyzerArn: str, resourceArn: str) -> None:
         """
-        [Client.start_resource_scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
+        [Client.start_resource_scan documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.start_resource_scan)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.untag_resource)
         """
 
     def update_archive_rule(
@@ -272,7 +310,7 @@ class AccessAnalyzerClient:
         clientToken: str = None,
     ) -> None:
         """
-        [Client.update_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
+        [Client.update_archive_rule documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_archive_rule)
         """
 
     def update_findings(
@@ -284,7 +322,7 @@ class AccessAnalyzerClient:
         resourceArn: str = None,
     ) -> None:
         """
-        [Client.update_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
+        [Client.update_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.update_findings)
         """
 
     def validate_policy(
@@ -296,7 +334,7 @@ class AccessAnalyzerClient:
         nextToken: str = None,
     ) -> ValidatePolicyResponseTypeDef:
         """
-        [Client.validate_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
+        [Client.validate_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Client.validate_policy)
         """
 
     @overload
@@ -304,7 +342,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_preview_findings"]
     ) -> ListAccessPreviewFindingsPaginator:
         """
-        [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+        [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
         """
 
     @overload
@@ -312,7 +350,7 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_access_previews"]
     ) -> ListAccessPreviewsPaginator:
         """
-        [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+        [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
         """
 
     @overload
@@ -320,13 +358,13 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_analyzed_resources"]
     ) -> ListAnalyzedResourcesPaginator:
         """
-        [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+        [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_analyzers"]) -> ListAnalyzersPaginator:
         """
-        [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+        [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
         """
 
     @overload
@@ -334,17 +372,25 @@ class AccessAnalyzerClient:
         self, operation_name: Literal["list_archive_rules"]
     ) -> ListArchiveRulesPaginator:
         """
-        [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+        [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_findings"]) -> ListFindingsPaginator:
         """
-        [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_policy_generations"]
+    ) -> ListPolicyGenerationsPaginator:
+        """
+        [Paginator.ListPolicyGenerations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["validate_policy"]) -> ValidatePolicyPaginator:
         """
-        [Paginator.ValidatePolicy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+        [Paginator.ValidatePolicy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
         """
