@@ -14,6 +14,7 @@ Usage::
         ListAnalyzersPaginator,
         ListArchiveRulesPaginator,
         ListFindingsPaginator,
+        ListPolicyGenerationsPaginator,
         ValidatePolicyPaginator,
     )
 
@@ -25,6 +26,7 @@ Usage::
     list_analyzers_paginator: ListAnalyzersPaginator = client.get_paginator("list_analyzers")
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
+    list_policy_generations_paginator: ListPolicyGenerationsPaginator = client.get_paginator("list_policy_generations")
     validate_policy_paginator: ValidatePolicyPaginator = client.get_paginator("validate_policy")
     ```
 """
@@ -41,6 +43,7 @@ from mypy_boto3_accessanalyzer.type_defs import (
     ListAnalyzersResponseTypeDef,
     ListArchiveRulesResponseTypeDef,
     ListFindingsResponseTypeDef,
+    ListPolicyGenerationsResponseTypeDef,
     PaginatorConfigTypeDef,
     SortCriteriaTypeDef,
     ValidatePolicyResponseTypeDef,
@@ -59,13 +62,14 @@ __all__ = (
     "ListAnalyzersPaginator",
     "ListArchiveRulesPaginator",
     "ListFindingsPaginator",
+    "ListPolicyGenerationsPaginator",
     "ValidatePolicyPaginator",
 )
 
 
 class ListAccessPreviewFindingsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+    [Paginator.ListAccessPreviewFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
     """
 
     def paginate(
@@ -76,26 +80,26 @@ class ListAccessPreviewFindingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAccessPreviewFindingsResponseTypeDef]:
         """
-        [ListAccessPreviewFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
+        [ListAccessPreviewFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
         """
 
 
 class ListAccessPreviewsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+    [Paginator.ListAccessPreviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
     """
 
     def paginate(
         self, analyzerArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListAccessPreviewsResponseTypeDef]:
         """
-        [ListAccessPreviews.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
+        [ListAccessPreviews.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
         """
 
 
 class ListAnalyzedResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+    [Paginator.ListAnalyzedResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     """
 
     def paginate(
@@ -113,13 +117,13 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzedResourcesResponseTypeDef]:
         """
-        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
+        [ListAnalyzedResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
         """
 
 
 class ListAnalyzersPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+    [Paginator.ListAnalyzers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     """
 
     def paginate(
@@ -128,26 +132,26 @@ class ListAnalyzersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnalyzersResponseTypeDef]:
         """
-        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
+        [ListAnalyzers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
         """
 
 
 class ListArchiveRulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+    [Paginator.ListArchiveRules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     """
 
     def paginate(
         self, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListArchiveRulesResponseTypeDef]:
         """
-        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
+        [ListArchiveRules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
         """
 
 
 class ListFindingsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+    [Paginator.ListFindings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     """
 
     def paginate(
@@ -158,13 +162,26 @@ class ListFindingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListFindingsResponseTypeDef]:
         """
-        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        [ListFindings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        """
+
+
+class ListPolicyGenerationsPaginator(Boto3Paginator):
+    """
+    [Paginator.ListPolicyGenerations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+    """
+
+    def paginate(
+        self, principalArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
+    ) -> Iterator[ListPolicyGenerationsResponseTypeDef]:
+        """
+        [ListPolicyGenerations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
         """
 
 
 class ValidatePolicyPaginator(Boto3Paginator):
     """
-    [Paginator.ValidatePolicy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+    [Paginator.ValidatePolicy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
     """
 
     def paginate(
@@ -175,5 +192,5 @@ class ValidatePolicyPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ValidatePolicyResponseTypeDef]:
         """
-        [ValidatePolicy.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.44/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
+        [ValidatePolicy.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
         """
